package org.faktorips.tutorial.produktdaten;

import org.faktorips.runtime.ClassloaderRuntimeRepository;
import org.faktorips.runtime.IRuntimeRepository;
import org.faktorips.tutorial.hausrat.hausrat.HausratModellRuntimeRepositoryFactory;
import org.faktorips.tutorial.modell.base.BaseModellRuntimeRepositoryFactory;

/**
 * Diese Klasse bietet Zugriff auf das FaktorIPS Runtime Repository.
 * 
 * <p>
 * Das Ablegen der {@code RuntimeRepositoryFactory} im gleichen Eclipse plug-in
 * Projekt wie das Produktdaten Repository stellt sicher, dass der Classloader
 * die das Repository XML finden kann.
 */
public class RuntimeRepositoryFactory {

	/** Pfad zum FaktorIPS repository. */
	static final String REPOSITORY_TOC_XML = "org/faktorips/tutorial/produktdaten/"
			+ "internal/faktorips-repository-toc.xml";

	/**
	 * Gibt das FaktorIPS Runtime-Repository zurück, dass die im Tutorial
	 * erstellte Produktkonfiguration enthält.
	 * 
	 * @return The {@code IRuntimeRepository}.
	 */
	public static IRuntimeRepository createRuntimeRepository(IRuntimeRepository hausratModellRepository) {
		IRuntimeRepository repository = ClassloaderRuntimeRepository.create(
				RuntimeRepositoryFactory.REPOSITORY_TOC_XML,
				RuntimeRepositoryFactory.class.getClassLoader());
		
		if (hausratModellRepository!=null) {
			repository.addDirectlyReferencedRepository(hausratModellRepository);
		}
		return repository;
	}
	
	/**
	 * Gibt das FaktorIPS Runtime-Repository zurück, dass die im Tutorial
	 * erstellte Produktkonfiguration enthält.
	 * 
	 * @return The {@code IRuntimeRepository}.
	 */
	public static IRuntimeRepository createRuntimeRepository() {
		IRuntimeRepository basedModellRepository = BaseModellRuntimeRepositoryFactory.createRuntimeRepository();
		IRuntimeRepository hausratModellRepository = HausratModellRuntimeRepositoryFactory.createRuntimeRepository(basedModellRepository);
		return createRuntimeRepository(hausratModellRepository);
	}
	
}
